import re
from django.db import models
from django import forms
from django.utils.translation import ugettext_lazy as _


class TagField(models.TextField):
    description = _('Tags as text field')

    __metaclass__ = models.SubfieldBase

    def __init__(self, *args, **kwargs):
        self.separator = kwargs.pop('separator', '|')
        kwargs['blank'] = kwargs.get('blank', True)
        super(TagField, self).__init__(*args, **kwargs)

    def get_prep_value(self, value):
        if isinstance(value, list):
            value = self.separator.join(value)
        return value

    def get_prep_lookup(self, lookup_type, value):
        return self.get_prep_value(value)

    def to_python(self, value):
        if not isinstance(value, list):
            value = value.split(self.separator)
        return value

    def value_from_object(self, obj):
        value = super(TagField, self).value_from_object(obj)
        if isinstance(value, list):
            complex_tags = [t for t in value if ' ' in t]
            if complex_tags:
                value = ', '.join(value)
            else:
                value = ' '.join(value)
        return value

    def formfield(self, **kwargs):
        defaults = {'widget': forms.TextInput}
        defaults.update(kwargs)
        return super(TagField, self).formfield(**defaults)



import re


class TagFormMixin(object):
    def __init__(self, *args, **kwargs):
        tag_field = kwargs.pop('tag_field', 'tags')
        tag_separators = kwargs.pop('tag_separators', ',')
        clean_method_name = 'clean_%s' % tag_field
        clean_method = self.clean_tags_method(tag_field, tag_separators)
        setattr(self, clean_method_name, clean_method)
        super(TagFormMixin, self).__init__(*args, **kwargs)

    def clean_tags_method(self, tag_field, tag_separators):
        def clean():
            value = self.cleaned_data[tag_field]
            space = ' '
            separators = tag_separators + space
            for separator in separators:
                dirty_tags = [t.strip() for t in value.split(separator)]
                tags = [t for t in dirty_tags if t]
                if separator is space and len(tags) == 1:
                    return tags
                elif len(tags) == 1:
                    continue
                return tags
        return clean



#!/usr/bin/env python
from setuptools import setup

setup(
    name='django-taggee',
    version='0.2',
    description='Tag field for Django models',
    keywords='django, tag, field',
    author='Dima Kurguzov',
    author_email='koorgoo@gmail.com',
    url='https://github.com/koorgoo/django-taggee/',
    license='MIT',
    packages=['taggee'],
    zip_safe=False,
    install_requires=[],
    include_package_delta=True,
    classifiers=[
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Framework :: Django',
        'Environment :: Web Environment'
    ],
)
